==> scrc-1.2.tar.gz: scrc-1.2/src/sim/Win32Thread.h <==
/************************************************************************/
/* Win32Thread.h: SpecC thread implementation based on Windows Threads	*/
/************************************************************************/
/* Author: Rainer Doemer			first version: 12/06/01 */
/************************************************************************/

/* last update: 12/10/01 */

/* modifications: (most recent first)
 *
 * 12/10/01 RD	introduced explicit return type of thread function
 * 12/06/01 RD	initial version (based on PosixThread.h)
 */

#ifndef WIN32_THREAD_H
#define WIN32_THREAD_H

#include <windows.h>

#include "specc.h"


/*** constants and macros ***********************************************/


	/* (none) */


/*** type definitions ***************************************************/


typedef DWORD (*thread_fct)(void*);	/* thread function type */
typedef DWORD thread_ret;		/* thread function return type */
typedef void *thread_arg;		/* thread function argument type */


/*** class declarations *************************************************/


	/***************************/
	/*** _specc::thread_base ***/
	/***************************/


class _specc::thread_base	/* base class for threads */
{
public:
thread_fct	ThreadFunction;	/* function performed by the thread */
thread_arg	ThreadArg;	/* argument to the function peformed */
thread_base	*ThreadCreator;	/* creator thread (only valid at creation) */
HANDLE		ThreadHandle;	/* handle for windows thread */
HANDLE		ThreadEvent;	/* start event of the thread */


thread_base(			/* constructor #1 */
	thread_base	*Creator);

~thread_base(void);		/* destructor */


static void ThreadStart(void);	/* initialize thread usage */

static void ThreadEnd(void);	/* clean up after thread usage */

void ThreadCreate(		/* create this new thread */
	thread_fct	Function,	/* (NULL for root thread) */
	thread_arg	Arg);		/* (NULL for root thread) */

void ThreadDelete(void);	/* delete this thread */

void ThreadJoin(		/* wait for another thread to complete */
	thread_base	*Thread);

void ThreadAbort(void);		/* abort this thread (force completion) */

void ThreadRun(			/* transfer control to another thread */
	thread_base	*Thread);
};


/*** exported variables *************************************************/


	/* none */


/************************************************************************/
/*** prototype definitions for exported functions		      ***/
/************************************************************************/


	/* none */


#endif /* WIN32_THREAD_H */

/* EOF Win32Thread.h */

==> scrc-2.2.tar.gz: scrc-2.2/src/sim/Win32Thread.h <==
/************************************************************************/
/* Win32Thread.h: SpecC thread implementation based on Windows Threads	*/
/************************************************************************/
/* Author: Rainer Doemer			first version: 12/06/01 */
/************************************************************************/

/* last update: 10/21/04 */

/* modifications: (most recent first)
 *
 * 10/21/04 RD	introduced SIM_THREAD_STACK_SIZE (passed from outside)
 * 06/15/04 PC  Adjustments for scrc 2.0
 * 04/12/04 RD	moved RunningThread into the thread_base class
 * 12/10/01 RD	introduced explicit return type of thread function
 * 12/06/01 RD	initial version (based on PosixThread.h)
 */

#ifndef WIN32_THREAD_H
#define WIN32_THREAD_H

#include <windows.h>

#include "specc.h"


/*** constants and macros ***********************************************/


#ifndef SIM_THREAD_STACK_SIZE		// default value (if not passed from outside):
#define SIM_THREAD_STACK_SIZE	0	// stack size for each thread
#endif /* SIM_THREAD_STACK_SIZE */	// (same as primary thread)


/*** type definitions ***************************************************/


typedef DWORD (*thread_fct)(void*);	/* thread function type */
typedef DWORD thread_ret;		/* thread function return type */
typedef void *thread_arg;		/* thread function argument type */


/*** class declarations *************************************************/


	/***************************/
	/*** _specc::thread_base ***/
	/***************************/


class _specc::thread_base	/* base class for threads */
{
public:
thread_fct	ThreadFunction;	/* function performed by the thread */
thread_arg	ThreadArg;	/* argument to the function peformed */
thread_base	*ThreadCreator;	/* creator thread (only valid at creation) */
HANDLE		ThreadHandle;	/* handle for windows thread */
HANDLE		ThreadEvent;	/* start event of the thread */

static thread_base	*RunningThread;	/* the running thread (or NULL) */


thread_base(			/* constructor #1 */
	thread_base	*Creator);

~thread_base(void);		/* destructor */


static void ThreadStart(void);	/* initialize thread usage */

static void ThreadEnd(void);	/* clean up after thread usage */

void ThreadCreate(		/* create this new thread */
	thread_fct	Function,	/* (NULL for root thread) */
	thread_arg	Arg);		/* (NULL for root thread) */

void ThreadDelete(void);	/* delete this thread */

void ThreadJoin(		/* wait for another thread to complete */
	thread_base	*Thread);

void ThreadAbort(void);		/* abort this thread (force completion) */

void ThreadRun(			/* transfer control to another thread */
	thread_base	*Thread);
};


/*** exported variables *************************************************/


	/* none */


/************************************************************************/
/*** prototype definitions for exported functions		      ***/
/************************************************************************/


	/* none */


#endif /* WIN32_THREAD_H */

/* EOF Win32Thread.h */
